@@ -94,10 +94,11 @@ sub processfile {
 		}
 	}
 
-	foreach (qw{task section relevance description key}, 
+	foreach (qw{task section relevance description key depends}, 
 	         grep(/^test-(.*)/, keys %fields)) {
 		print OUT ucfirst($_).": ".$fields{$_}."\n" if length $fields{$_};
 	}
+	print OUT "Packages: task-fields\n";
 	print OUT "\n";
 }
 
