@@ -396,8 +396,11 @@ sub main {
 	}
 	
 	# The interactive bit.
+	my $interactive=0;
+	my $manual_selection=0;
 	my @list = order_for_display(grep { $_->{_display} == 1 } @tasks);
 	if (@list && ! $options{"no-ui"} && ! $options{install} && ! $options{remove}) {
+		$interactive=1;
 		if (! $options{"new-install"}) {
 			# Find tasks that are already installed.
 			map { $_->{_installed} = task_installed($_) } @list;
@@ -428,7 +431,7 @@ sub main {
 		close IN;
 		unlink $tmpfile;
 		if ($ret=~/manual package selection/) {
-			unshift @aptitude_install, "--visual-preview";
+			$manual_selection=1;
 		}
 		
 		# Set _install flags based on user selection.
@@ -444,10 +447,6 @@ sub main {
 				push @aptitude_remove, task_packages($task, 0);
 			}
 		}
-		# Clear screen before running aptitude.
-		if ((@aptitude_remove || @aptitude_install) && ! $options{test}) {
-			system("clear");
-		}
 	}
 
 	# Mark dependnent packages for install if their dependencies are met.
@@ -463,7 +462,13 @@ sub main {
 	}
 
 	# Add tasks to install.
-	push @aptitude_install, map { task_packages($_, 1) } grep { $_->{_install} } @tasks;
+	my @to_install=map { task_packages($_, 1) } grep { $_->{_install} } @tasks;
+	push @aptitude_install, @to_install;
+	
+	# Clear screen before running aptitude.
+	if ($interactive && (@aptitude_remove || @aptitude_install) && ! $options{test}) {
+		system("clear");
+	}
 
 	# Remove any packages we were asked to.
 	if (@aptitude_remove) {
@@ -473,28 +478,33 @@ sub main {
 		else {
 			my $ret=system("aptitude", "remove", @aptitude_remove) >> 8;
 			if ($ret != 0) {
-				error gettext("aptitude failed");
+				error gettext("aptitude failed")." ($ret)";
 			}
 		}
 	}
 	
 	# And finally, act on selected tasks.
-	if (@aptitude_install) {
-		# If aptitude is just being run with no tasks preselected 
-		# to install, remove the --visual-preview parameter and
-		# just go to regular aptitude.
-		if (@aptitude_install == 1 && $aptitude_install[0] eq "--visual-preview") {
+	if (@aptitude_install || $manual_selection) {
+		# If the user selected no tasks and manual package
+		# selection, run aptitude w/o the --visual-preview parameter.
+		if (! @to_install && $manual_selection) {
 			if ($options{test}) {
 				print "aptitude\n";
 			}
 			else {
 				my $ret=system("aptitude") >> 8;
 				if ($ret != 0) {
-					error gettext("aptitude failed");
+					error gettext("aptitude failed")." ($ret)";
 				}
 			}
 		}
 		else {
+			# Manaul selection and task installs, as best
+			# aptitude can do it currently.
+			if ($manual_selection) {
+				unshift @aptitude_install, "--visual-preview";
+			}
+			
 			if ($options{test}) {
 				print "aptitude --without-recommends -y install ".join(" ", @aptitude_install)."\n";
 			}
